pub struct Ide {
pub name: String,
/* private fields */
}Fields
name: StringTrait Implementations
Sourceimpl DatabaseObject for Ide
impl DatabaseObject for Ide
type Id = Vec<u8>
Sourcefn write_to_db<'e>(
&'e self,
executor: impl SqliteExecutor<'e> + 'e,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'e>>
fn write_to_db<'e>( &'e self, executor: impl SqliteExecutor<'e> + 'e, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'e>>
Write the given instance of the object to the database.
Sourcefn from_db<'e>(
id: Self::Id,
executor: impl SqliteExecutor<'e> + 'e,
) -> Pin<Box<dyn Future<Output = Result<Self>> + Send + 'e>>
fn from_db<'e>( id: Self::Id, executor: impl SqliteExecutor<'e> + 'e, ) -> Pin<Box<dyn Future<Output = Result<Self>> + Send + 'e>>
Retrieve the given object from the database.
Sourcefn exists<'e>(
&'e self,
executor: impl SqliteExecutor<'e> + 'e,
) -> Pin<Box<dyn Future<Output = Result<bool>> + Send + 'e>>
fn exists<'e>( &'e self, executor: impl SqliteExecutor<'e> + 'e, ) -> Pin<Box<dyn Future<Output = Result<bool>> + Send + 'e>>
Check if the given object exists in the database
Sourcefn all_names<'e>(
executor: impl SqliteExecutor<'e> + 'e,
) -> Pin<Box<dyn Future<Output = Result<Vec<Self>>> + Send + 'e>>
fn all_names<'e>( executor: impl SqliteExecutor<'e> + 'e, ) -> Pin<Box<dyn Future<Output = Result<Vec<Self>>> + Send + 'e>>
Retrieve all unique names
Sourcefn remove_from_db<'e>(
&'e self,
executor: impl SqliteExecutor<'e> + 'e,
) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'e>>
fn remove_from_db<'e>( &'e self, executor: impl SqliteExecutor<'e> + 'e, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'e>>
Remove the given object from the database
Sourceimpl<'de> Deserialize<'de> for Ide
impl<'de> Deserialize<'de> for Ide
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for Ide
impl Ord for Ide
Sourceimpl PartialOrd for Ide
impl PartialOrd for Ide
impl Eq for Ide