Episko Library
This library is part of the projekt Episko. It provides functionality and interfaces to create and manage metadata for projects.
Structure
The library is structured into the following modules:
- metadata
- files
- database
The metadata module is part of the core crate, while the files module is placed under the “files” feature flag, which is however enabled by default.
Disabling default features may lead to errors, as currently macros are used in the core crate that don’t work without some of the features. This needs to be adressed at a later point in the project.
Detailed documentation can be found within each module.
Modules
- config
- This module contains everything relevant regarding the config used by the gui and cli application.
- database
- Database Module
- files
- File serialization and deserialization
- metadata
- Metadata used within the project
- statistics
- Statistics about all projects
Traits
- ApplyIf
- Trait to perform a self consuming action based on a condition.
Functions
- greet
- Placeholder used as a command by tauri